function phat = gumbfit(data1)
%GUMBFIT Parameter estimates for Gumbel data.
%
% CALL: phat = gumbfit(data) 
%
%     phat = the maximum likelihood estimates of the  
%            parameters of the Gumbel distribution given the data.
%     parmci  = 95% confidence intervals
%     data = data vector

% Example:
%   R = gumbrnd(1,2,1,100,1);
%   [phat, ci] = gumbfit(R)
%
% See also: gumbplot, gumbcdf, empdistr

% Reference: 
%  Johnson  N.L., Kotz S. and Balakrishnan, N. (1994)
%  Continuous Univariate Distributions, Volume 2. Wiley. 

  phat= evfit(-data1);
  hata=phat(2);
  hatb=-phat(1);
  phat=[hata,hatb];
end


