function f = gumbpdf(x,a,b)
%GUMBPDF Gumbel probability density function.
%
% CALL:  f = gumbpdf(x,a,b) 
%   
%   f    = Gumbel pdf evaluated at x
%  a, b  = parameters of the Gumbel distribution.
%
%  Gumbel PDF  is given by :                           
%      f(x) = exp(-(x-b)/a)*exp(-exp(-(x-b)/a))/a    -inf < x < inf, a>0
%
% Example: 
%   x = linspace(-4,8,200);
%   p1 = gumbpdf(x,2);
%   plot(x,p1)
%
% See also: gumbfit, gumbrnd, gumbcdf, gumbinv, gumbstat

% Reference: 
%  Johnson  N.L., Kotz S. and Balakrishnan, N. (1994)
%  Continuous Univariate Distributions, Volume 2. Wiley. 

f=evpdf(-x,-b,a);
