function [scaleparameterhat, sigmahat, bhat]=logn3fit(x,flag)
%LOGN3FIT Parameter estimates for 3-parameter lognormal data.
%   [X0HAT,SIGMAHAT,BHAT] = LOGN3FIT(X,0) or [X0HAT,SIGMAHAT,BHAT] = LOGN3FIT(X)
%   gives estimates of the three (3) parameters x0>0, sigma>0, and b, given by 
%   
%      X-b
%   ln(---) \in N(0;sigma^2),   (natural logarithm)
%      x0
%
%   where X is a 3-parameter lognormally distributed random variable.
%
%   [MUHAT,SIGMAHAT,BHAT] = LOGN3FIT(X,1) gives estimates of the three (3) parameters
%   mu, sigma>0, and b, given by
%   
%   ln(X-b) \in N(mu;sigma^2),   (natural logarithm)
%
%   where X is a 3-parameter lognormally distributed random variable.
%
%   See also LOGN3PLOT, LOGNCDF, LOGNINV, LOGNPDF, LOGNRND, LOGNSTAT.
%

% Written by Tord Rikte 2002-02-xx.
% Revised by Tord Rikte 2003-03-19.

if nargin<1
  error('The data vector must be specified.')
end
if nargin<2
  flag=0;
end
bhat=fminsearch('logn3like',2*min(x)-max(x),[],x);
n=length(x);
muhat=mean(log(x-bhat));
sigmahat=sqrt(sum((log(x-bhat)-muhat).^2)/length(x));
if flag
  scaleparameterhat=muhat;
else
  scaleparameterhat=exp(muhat);
end