function y=logn3like(b,data);
%LOGN3LIKE Negative and scaled log-likelihood function for the 3-parameter lognormal distribution.
%   L = NORMLIKE(B,DATA) returns the negative and scaled log-likelihood 
%   function for the 3-parameter lognormal distributions. This is for the
%   parameter b only. The length of the vector L is the length of the vector B.
%
%   LOGN3LIKE is a utility function for the maximum likelihood estimation in LOGN3FIT.
%
%   See also LOGN3FIT, BETALIKE, GAMLIKE, MLE, NORMFIT, WEIBLIKE. 
%

% Written by Tord Rikte 2002-02-xx.

n=length(data);
a=size(b);
b=b(:);
y=zeros(size(b));
for i=1:length(b)
  if b(i)>=min(data)
    y(i)=Inf;
  else
    s=sqrt(sum((log(abs(data-b(i)))-mean(log(abs(data-b(i))))).^2));
    y(i)=n*log(s)+sum(log(abs(data-b(i))));
  end
end
y=reshape(y,a);