function [y,xrad]=sinunits(x,angleunit,varargin)
%SINUNITS Sine of angle given in other units than 1 rad
%
%    SINUNITS(X,UNIT) is the sine of the elemnts in X
%    when measured in the unit UNIT. Currently supported
%    are UNIT='rad' (radians) 'deg' (degrees),
%    'gon' (gon), 'min' (minutes), 'sec' (seconds), 
%    and '-' (Swedish military points).
%    Default is UNIT='rad'.
%    [Y,XRAD]=SINUNITS(X,UNIT): Here, firstly, Y will
%    contain the sine values of  the elements in X (when
%    X is measured in the unit UNIT), and, secondly,
%    XRAD will contain the values of X converted into
%    the unit 1 rad (radians).
%
if nargin>=3, error('Too many input arguments.'), end
if nargin==0, error('Too few input arguments.'), end
if nargin==1, angleunit='rad', end
if ~ischar(angleunit), error('Argument angleunit is not char.'), end
if ~isreal(x), error('Argument x is not real.'), end

if strcmp(angleunit,'rad')
  xrad=x;
elseif strcmp(angleunit,'deg')
  xrad=pi*x/180;
elseif strcmp(angleunit,'gon')
  xrad=pi*x/200;
elseif strcmp(angleunit,'min')
  xrad=pi*x/(180*60);
elseif strcmp(angleunit,'sec')
  xrad=pi*x/(180*3600);
elseif strcmp(angleunit,'-')
  xrad=pi*x/3150;
else
  error(['The unit ''' angleunit ''' is not supported'])
end

y=sin(xrad);