function R = wweibrnd(a,c,varargin)
%WWEIBRND Random matrices a the Weibull distribution.
% 
% CALL:  R = wweibrnd(a,c,sz)
% 
% R     = a matrix of random numbers from the Weibull distribution
% a, c  = parameters of the Weibull distribution
%    sz = size(R)    (Default common size of k,s and m0)
%         sz can be a comma separated list or a vector 
%         giving the size of R (see zeros for options).
%
% The Weibull distribution is defined by the distribution function
% 
%   F(x) = 1 - exp(-(x/a)^c), x>=0, a,b>0
% 
% The random numbers are generated by the inverse method. 
%
% Example:
%   R=wweibrnd(1,10,1,100);
%   phat=wweibplot(R)
%
% See also: wweibinv

% Reference: Cohen & Whittle, (1988) "Parameter Estimation in Reliability
% and Life Span Models", p. 25 ff, Marcel Dekker.


% Tested on: matlab 5.3
% History: 
% revised pab 23.10.2000
%  - added comnsize
%  - added greater flexibility on the sizing of R
% rewritten ms 15.06.2000

error(nargchk(2,inf,nargin))
if nargin==2,
  [errorcode a c] = comnsize(a,c);
else
  [errorcode a c] = comnsize(a,c,zeros(varargin{:}));
end
if errorcode > 0
    error('a and c must be of common size or scalar.');
end
csiz=size(a);
R = wweibinv(rand(csiz),a,c);





